@@ -8,22 +8,15 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
-import aws_cdk.aws_dynamodb._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_lambda_event_sources._jsii
-import aws_cdk.aws_sqs._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-dynamodbstreams-lambda",
-    "1.181.0",
+    "2.0.0",
     __name__[0:-6],
-    "aws-dynamodbstreams-lambda@1.181.0.jsii.tgz",
+    "aws-dynamodbstreams-lambda@2.0.0.jsii.tgz",
 )
 
 __all__ = [
